ColabClient

Struct ColabClient 

pub struct ColabClient { /* private fields */ }

Implementations

Source

impl ColabClient

pub fn new<F, Fut>(config: &ColabConfig, get_access_token: F) -> Result<Self>
where F: Fn() -> Fut + Send + Sync + 'static, Fut: Future<Output = Result<String>> + Send + 'static,

pub async fn list_assignments(&self) -> Result<Vec<ListedAssignment>>

pub async fn assign( &self, notebook_hash: Uuid, variant: Variant, accelerator: Option<&str>, shape: Shape, ) -> Result<(Assignment, bool)>

pub async fn unassign(&self, endpoint: &str) -> Result<()>

pub async fn refresh_connection( &self, endpoint: &str, ) -> Result<RuntimeProxyInfo>

pub async fn list_sessions_via_tunnel( &self, endpoint: &str, ) -> Result<Vec<Session>>

pub async fn delete_session( &self, proxy_url: &str, proxy_token: &str, session_id: &str, ) -> Result<()>

pub async fn create_terminal( &self, proxy_url: &str, proxy_token: &str, ) -> Result<JupyterTerminal>

pub async fn delete_terminal( &self, proxy_url: &str, proxy_token: &str, terminal_name: &str, ) -> Result<()>

Delete a Jupyter terminal that was previously created with create_terminal. Used to cleanly reap the remote process tree belonging to a specific short-lived view (e.g. server ps) without touching unrelated sessions or the assigned server itself.

pub fn terminal_ws_url(&self, proxy_url: &str, terminal_name: &str) -> String

pub async fn upload_file_streaming( &self, proxy_url: &str, proxy_token: &str, remote_path: &str, file_path: &Path, progress: impl Fn(u64) + Send + 'static, ) -> Result<()>

pub async fn send_keep_alive(&self, endpoint: &str) -> Result<()>

pub async fn get_ccu_info(&self) -> Result<CcuInfo>